package com.qmth.eds.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.eds.common.contant.SystemConstant;
import com.qmth.eds.job.service.JobService;
import com.qmth.eds.service.ExamSyncTotalService;
import com.qmth.eds.common.util.Result;
import com.qmth.eds.common.util.ResultUtil;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/exam_sync_total")
public class ExamSyncTotalController {

    @Resource
    private ExamSyncTotalService examSyncTotalService;

    @Resource
    private JobService jobService;

    /**
     * 查询
     *
     * @param syncDate   同步日期
     * @param pageNumber 分页参数
     * @param pageSize   分页参数
     */
    @ApiOperation(value = "查询")
    @PostMapping("/page")
    public Result page(@RequestParam(value = "syncDate", required = false) Long syncDate,
                       @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                       @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(examSyncTotalService.list(syncDate, pageNumber, pageSize));
    }

    /**
     * 下载
     *
     * @param id       id
     * @param writeLog 是否写入日志（考务数据列表下载需要，下载列表下载不需要）
     */
    @ApiOperation(value = "下载")
    @PostMapping("/download")
    public void page(@RequestParam(value = "id", required = false) Long id,
                     @RequestParam(value = "writeLog", defaultValue = "true") Boolean writeLog,
                     HttpServletResponse response) {
        examSyncTotalService.download(id, writeLog, response);
    }

    /**
     * 人工同步
     */
    @ApiOperation(value = "人工同步")
    @PostMapping("/manual_sync")
    @Aac(auth = BOOL.FALSE)
    public Result manualSync() {
        jobService.getExamData(false);
        return ResultUtil.success(true);
    }
}
