package com.qmth.eds.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.eds.bean.dto.syssetting.SettingObject;
import com.qmth.eds.common.contant.SystemConstant;
import com.qmth.eds.common.entity.BasicSchool;
import com.qmth.eds.common.entity.SysSetting;
import com.qmth.eds.common.enums.ExceptionResultEnum;
import com.qmth.eds.common.util.ServletUtil;
import com.qmth.eds.mapper.SysSettingMapper;
import com.qmth.eds.service.CommonCacheService;
import com.qmth.eds.service.SysSettingService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 系统设置 服务实现类
 * </p>
 */
@Service
public class SysSettingServiceImpl extends ServiceImpl<SysSettingMapper, SysSetting> implements SysSettingService {

    @Resource
    CommonCacheService commonCacheService;

    @Override
    public List<SettingObject> getData() {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        QueryWrapper<SysSetting> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SysSetting::getSchoolId, schoolId);
        List<SysSetting> sysSettingList = this.list(queryWrapper);

        SysSetting sysSetting = new SysSetting();
        // 第一次设置，初始化数据
        if (sysSettingList.isEmpty()) {
            BasicSchool basicSchool = commonCacheService.schoolCache(schoolId);
            sysSetting = SysSetting.init(basicSchool);
            this.save(sysSetting);
        } else if (sysSettingList.size() > 1) {
            throw ExceptionResultEnum.ERROR.exception("系统设置有误，查出多条数据");
        }

        if (!sysSettingList.isEmpty()) {
            sysSetting = sysSettingList.get(0);
        }

        return JSON.parseArray(sysSetting.getParameterObject(), SettingObject.class);
    }

    @Override
    public boolean saveData(List<SettingObject> settingObjects) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        Long userId = Long.valueOf(ServletUtil.getRequestUserId().toString());

        QueryWrapper<SysSetting> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SysSetting::getSchoolId, schoolId);
        SysSetting sysSetting = this.getOne(queryWrapper);

        String parameterObject = JSON.toJSONString(settingObjects);
        // 新增
        if (sysSetting == null) {
            sysSetting = new SysSetting();
            sysSetting.setId(SystemConstant.getDbUuid());
            sysSetting.setParameterObject(parameterObject);
            sysSetting.setSchoolId(schoolId);
            sysSetting.setCreateId(userId);
            sysSetting.setCreateTime(System.currentTimeMillis());
        } else {
            sysSetting.setParameterObject(parameterObject);
            sysSetting.setUpdateId(userId);
            sysSetting.setUpdateTime(System.currentTimeMillis());
            commonCacheService.removeSysSetting(schoolId);
        }
        return this.saveOrUpdate(sysSetting);
    }

    @Override
    public SysSetting getBySchoolId(Long schoolId) {
        QueryWrapper<SysSetting> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(SysSetting::getSchoolId, schoolId);
        return this.getOne(queryWrapper);
    }
}
